<?php
/**********************************************************************************
 *   Copyright(C) 2002 David Stevens, 2004 Michael T. Garrison Stuber
 *
 *   This file is part of OpenBiblio.
 *
 *   OpenBiblio is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   OpenBiblio is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with OpenBiblio; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********************************************************************************
 */

require_once("../shared/global_constants.php");
require_once("../classes/Query.php");
require_once("../classes/BiblioField.php");
require_once("../classes/Localize.php");

/******************************************************************************
 * BiblioBrowseiSubjects data access component for browsing library subjects
 *
 * @author Michael T. Garrison Stuber <mstuber@yahoo.com>;
 * @version 1.0
 * @access public
 ******************************************************************************
 */
class BiblioBrowseSubjects extends Query {
  var $_itemsPerPage = 1;
  var $_rowNmbr = 0;
  var $_currentRowNmbr = 0;
  var $_currentPageNmbr = 0;
  var $_rowCount = 0;
  var $_pageCount = 0;
  var $_loc;

  function BiblioBrowseSubjects () {
    $this->_loc = new Localize(OBIB_LOCALE,"classes");
  }
  function setItemsPerPage($value) {
    $this->_itemsPerPage = $value;
  }
  function getLineNmbr() {
    return $this->_rowNmbr;
  }
  function getCurrentRowNmbr() {
    return $this->_currentRowNmbr;
  }
  function getRowCount() {
    return $this->_rowCount;
  }
  function getPageCount() {
    return $this->_pageCount;
  }

  /****************************************************************************
   * Executes a query
   * @param string @$words pointer to an array containing words to search for
   * @param integer $page What page should be returned if results are more than one page
   * @return boolean returns false, if error occurs
   * @access public
   ****************************************************************************
   */
  function search(&$words, $page) {
    # reset stats
    $this->_rowNmbr = 0;
    $this->_currentRowNmbr = 0;
    $this->_currentPageNmbr = $page;
    $this->_rowCount = 0;
    $this->_pageCount = 0;

	$sql = "";

	#This probably won't work real well for multi word searches.  Put another way, you'll get an "AND"
	#query instead of an "OR" query

	$searchwords = join(" ", $words);

	#echo "<p>Searching for $searchwords</p>\n";

	for($i = 1; $i < 6; $i++) {
		$sql = $sql . "select distinct topic" . $i . " \"topic\" from biblio where topic" . $i . " like '%" . $searchwords . "%' and topic" . $i . " != ''";
		if($i < 5) {
				$sql = $sql . " union ";
		}
	}
	
    $sql = $sql." order by topic ";

	# MySQL is (currently) too braindead to do views, and hence doing a select count against
	# a composite view is not an option.  Instead, we do the query twice, and grab the
	# number of rows from the query engine.

	#echo "<p>$sql</p>";
	
    if (!$this->_conn->exec($sql)) {
      $this->_errorOccurred = true;
      $this->_error = $this->_loc->getText("biblioSubjectBrowseErr1");
      $this->_dbErrno = $this->_conn->getDbErrno();
      $this->_dbError = $this->_conn->getDbError();
      $this->_SQL = $sql;
      return false;
    }
	else {
	  $this->_rowCount = $this->_conn->numRows();
	  #echo "<p> Row count is: $this->_rowCount </P>";
	}
    
	# setting limit so we can page through the results
    $offset = ($page - 1) * $this->_itemsPerPage;
    $limit = $this->_itemsPerPage;
    $sql = $sql." limit ".$offset.",".$limit;

    # Calculate stats based on row count
    $this->_pageCount = ceil($this->_rowCount / $this->_itemsPerPage);

    # Running search sql statement
    $result = $this->_conn->exec($sql);
    if ($result == false) {
      $this->_errorOccurred = true;
      $this->_error = $this->_loc->getText("biblioSubjectBrowseErr2");
      $this->_dbErrno = $this->_conn->getDbErrno();
      $this->_dbError = $this->_conn->getDbError();
      $this->_SQL = $sql;
      return false;
    }

    return $result;
  }
 
  /****************************************************************************
   * Fetches a row from the query result and returns a subect.
   * @return BiblioBrowse returns a subject or false if no more subjects to fetch
   * @access public
   ****************************************************************************
   */
  function fetchRow() {
    $array = $this->_conn->fetchRow();
    if ($array == false) {
      return false;
    }

    # increment rowNmbr
    $this->_rowNmbr = $this->_rowNmbr + 1;
    $this->_currentRowNmbr = $this->_rowNmbr + (($this->_currentPageNmbr - 1) * $this->_itemsPerPage);

    return $array["topic"];
  }



}

?>
