<?php
/**********************************************************************************
 *   Copyright(C) 2002 David Stevens
 *
 *   This file is part of OpenBiblio.
 *
 *   OpenBiblio is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   OpenBiblio is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with OpenBiblio; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********************************************************************************
 */

  require_once("../classes/Localize.php");

/******************************************************************************
 * Dm represents a domain table row.
 *
 * @author David Stevens <dave@stevens.name>;
 * @version 1.0
 * @access public
 ******************************************************************************
 */
class Dm {
  var $_code = "";
  var $_description = "";
  var $_descriptionError = "";
  var $_defaultFlg = "";
  var $_daysDueBack = "0";
  var $_daysDueBackError = "";
  var $_dailyLateFee = "0";
  var $_dailyLateFeeError = "";
  var $_adultCheckoutLimit = "0";
  var $_adultCheckoutLimitError = "";
  var $_adultRenewalLimit = "0";
  var $_adultRenewalLimitError = "";
  var $_juvenileCheckoutLimit = "0";
  var $_juvenileCheckoutLimitError = "";
  var $_juvenileRenewalLimit = "0";
  var $_juvenileRenewalLimitError = "";
  var $_imageFile = "";
  var $_count = "0";

  function Dm () {
    $this->_loc = new Localize(OBIB_LOCALE,"classes");
  }

  /****************************************************************************
   * @return boolean true if data is valid, otherwise false.
   * @access public
   *
   * TODO: Error responses need to be internationalised
   ****************************************************************************
   */
  function validateData() {
    $valid = true;
    if ($this->_description == "") {
      $valid = false;
      $this->_descriptionError = $this->_loc->getText("DmErr1");
    }
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_daysDueBack,
                $this->_daysDueBackError,
                $this->_loc->getText("DmErr2"),
                $this->_loc->getText("DmErr3"));
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_dailyLateFee,
                $this->_dailyLateFeeError,
                $this->_loc->getText("DmErr4"),
                $this->_loc->getText("DmErr5"));
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_adultCheckoutLimit,
                $this->_adultCheckoutLimitError,
                $this->_loc->getText("DmErr6"),
                $this->_loc->getText("DmErr7"));
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_adultRenewalLimit, $this->_adultRenewalLimitError,
                $this->_loc->getText("DmErr8"),
                $this->_loc->getText("DmErr9"));
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_juvenileCheckoutLimit,
                $this->_juvenileCheckoutLimitError,
                $this->_loc->getText("DmErr10"),
                $this->_loc->getText("DmErr11"));
    $this->_validateFieldNumericAndPositiveOrZero($valid,
                $this->_juvenileRenewalLimit,
                $this->_juvenileRenewalLimitError,
                $this->_loc->getText("DmErr12"),
                $this->_loc->getText("DmErr13"));
    return $valid;
  }

  /****************************************************************************
   * Validation Function. Ensures the specified field is numeric and a positive
   * number (zero is ok).
   *
   * @param boolean $valid                 Set to false if the specified field is not validate
   * @param string  $fieldToValidate       Specified field to validate
   * @param string  $errorResponse         Populated with the appropriate error message if validation fails
   * @param string  $mustBeNumericErrorMsg Error Message to use on a numeric validation failure
   * @param string  $mustBePositiveOrZeroErrorMsg Error Message to use on a positive or zero validation failure
   *
   * @return void
   * @access private
   ****************************************************************************
   */
  function _validateFieldNumericAndPositiveOrZero(&$valid, &$fieldToValidate, &$errorResponse, $mustBeNumericErrorMsg, $mustBePositiveOrZeroErrorMsg) {
    if (!is_numeric($fieldToValidate)) {
      $valid = false;
      $errorResponse = $mustBeNumericErrorMsg;
    } elseif ($fieldToValidate < 0) {
      $valid = false;
      $errorResponse = $mustBeGtErrorMsg;
    }
  }

  /****************************************************************************
   * Getter methods for all fields
   * @return string
   * @access public
   ****************************************************************************
   */
  function getCode() {
    return $this->_code;
  }
  function getDescription() {
    return $this->_description;
  }
  function getDescriptionError() {
    return $this->_descriptionError;
  }
  function getDefaultFlg() {
    return $this->_defaultFlg;
  }
  function getDaysDueBack() {
    return $this->_daysDueBack;
  }
  function getDaysDueBackError() {
    return $this->_daysDueBackError;
  }
  function getDailyLateFee() {
    return $this->_dailyLateFee;
  }
  function getDailyLateFeeError() {
    return $this->_dailyLateFeeError;
  }
  function getAdultCheckoutLimit() {
    return $this->_adultCheckoutLimit;
  }
  function getAdultCheckoutLimitError() {
    return $this->_adultCheckoutLimitError;
  }
  function getAdultRenewalLimit() {
    return $this->_adultRenewalLimit;
  }
  function getAdultRenewalLimitError() {
    return $this->_adultRenewalLimitError;
  }
  function getJuvenileCheckoutLimit() {
    return $this->_juvenileCheckoutLimit;
  }
  function getJuvenileCheckoutLimitError() {
    return $this->_juvenileCheckoutLimitError;
  }
  function getJuvenileRenewalLimit() {
    return $this->_juvenileRenewalLimit;
  }
  function getJuvenileRenewalLimitError() {
    return $this->_juvenileRenewalLimitError;
  }
  function getImageFile() {
    return $this->_imageFile;
  }
  function getCount() {
    return $this->_count;
  }

  /****************************************************************************
   * Generic setter method for numeric fields. Ensures the value set is trimmed,
   * and defaulting to 0 if an empty field is passed.
   *
   * @param string $valueToSet New value to set
   * @param string $destinationField The destination field
   *
   * @return void
   * @access private
   ****************************************************************************
   */
  function _setNumeric(&$valueToSet, &$destinationField) {
    if (trim($valueToSet) == "") {
      $destinationField = "0";
    } else {
      $destinationField = trim($valueToSet);
    }
  }

  /****************************************************************************
   * Setter methods for all fields
   * @param string $value new value to set
   * @return void
   * @access public
   ****************************************************************************
   */
  function setCode($value) {
    $this->_code = trim($value);
  }
  function setDescription($value) {
    $this->_description = trim($value);
  }
  function setDescriptionError($value) {
    $this->_descriptionError = trim($value);
  }
  function setDefaultFlg($value) {
    $this->_defaultFlg = trim($value);
  }
  function setDaysDueBack($value) {
    $this->_setNumeric($value, $this->_daysDueBack);
  }
  function setDaysDueBackError($value) {
    $this->_daysDueBackError = trim($value);
  }
  function setDailyLateFee($value) {
    $this->_setNumeric($value, $this->_dailyLateFee);
  }
  function setDailyLateFeeError($value) {
    $this->_dailyLateFeeError = trim($value);
  }
  function setAdultCheckoutLimit($value) {
    $this->_setNumeric($value, $this->_adultCheckoutLimit);
  }
  function setAdultCheckoutLimitError($value) {
    $this->_adultCheckoutLimitError = trim($value);
  }
  function setAdultRenewalLimit($value) {
    $this->_setNumeric($value, $this->_adultRenewalLimit);
  }
  function setAdultRenewalLimitError($value) {
    $this->_adultRenewalLimitError = trim($value);
  }
  function setJuvenileCheckoutLimit($value) {
    $this->_setNumeric($value, $this->_juvenileCheckoutLimit);
  }
  function setJuvenileCheckoutLimitError($value) {
    $this->_juvenileCheckoutLimitError = trim($value);
  }
  function setJuvenileRenewalLimit($value) {
    $this->_setNumeric($value, $this->_juvenileRenewalLimit);
  }
  function setJuvenileRenewalLimitError($value) {
    $this->_juvenileRenewalLimitError = trim($value);
  }
  function setImageFile($value) {
    $this->_imageFile = trim($value);
  }
  function setCount($value) {
    $this->_setNumeric($value, $this->_count);
  }


}

?>
